@@ -16,7 +16,7 @@ class BeamTrace:
 
     ### Process:
     User adds in mirrors, lenses, and spaces *in sequential order*.
-    User computes the cavity ABCD matrix from the components added using calculate_cavity_ABCD().
+    User computes the cavity abcd matrix from the components added using calculate_cavity_abcd().
     If cavity is stable, find the fundamental eigenmode for the beam (q-parameter)
     Set this q-parameter as q_input beam.
     Scan the cavity beam parmater using scan_cavity().
@@ -26,11 +26,11 @@ class BeamTrace:
     import numpy as np
     from beamtrace import BeamTrace
 
-    my_cav = BeamTrace()        # initializes ABCD class
+    my_cav = BeamTrace()        # initializes abcd class
     my_cav.add_mirror(1.0) # adds mirror with 1.0 meter radius of curvature at z=0.0 meters
     my_cav.add_space(0.5)  # adds 0.5 meters of space to cavity
     my_cav.add_mirror(1.0) # adds mirror with 1.0 meter radius of curvature at z=0.5 meters
-    my_cav.calculate_cavity_ABCD() # Finds the cavity round-trip ABCD matrix, tells you if it's stable.  If it is stable, populates the my_cav.q_input parameter
+    my_cav.calculate_cavity_abcd() # Finds the cavity round-trip abcd matrix, tells you if it's stable.  If it is stable, populates the my_cav.q_input parameter
     zz, ww, gouy, qq = my_cav.scan_cavity(round_trip=True) # Returns propagation distance, beam radius, accumulated gouy phase, and beam q-parameter for the entire cavity, plus the round-trip
 
     import matplotlib.pyplot as plt
@@ -54,17 +54,46 @@ class BeamTrace:
     plt.show()
     """
 
-    def __init__(self, isCavity=True, verbose=True, wavelength=1064e-9):
-        self.isCavity = isCavity
+    def __init__(
+        self, is_cavity=True, is_single_pass=False, verbose=True, wavelength=1064e-9
+    ):
+        """Constructor for BeamTrace class.
+
+        Inputs:
+        -------
+        is_cavity: bool
+            sets whether this beam trace is of a cavity
+        is_single_pass: bool
+            sets whether a cavity is single pass or double pass,
+            i.e. does the beam go only one direction through the cavity, like in the mode cleaner cavities,
+            or does it go back and forth, like in the arm cavity.
+            Only relevant if is_cavity == True.
+        verbose: bool
+            will print helpful messages if True
+        wavelength: float
+            wavelength of the laser.  Default is 1064e-9 meters.
+        """
+        self.is_cavity = is_cavity
+        self.is_single_pass = is_single_pass
         self.verbose = verbose
         self.wavelength = wavelength
 
-        self.isStable = False  # cavity is never stable straightaway
-        self.isUnity = True
+        if self.verbose:
+            print("\033[92m")
+            print("BeamTrace class initial attributes")
+            print("\033[0m")
+            print(f"self.is_cavity = {self.is_cavity}")
+            print(f"self.is_single_pass = {self.is_single_pass}")
+            print(f"self.verbose = {self.verbose}")
+            print(f"self.wavelength = {self.wavelength} m")
+            print()
+
+        self.is_stable = False  # cavity is never stable straightaway
+        self.is_unity = True
 
         self.q_input = None  # for a cavity, the input q-parameter for a stable cav
         self.w_input = None  # for a cavity, the input beam radius
-        self.RoC_input = None  # for a cavity, the input radius of curvature
+        self.roc_input = None  # for a cavity, the input radius of curvature
 
         self.input_mirror_name = None  # for a cavity, the input mirror name
         self.end_mirror_name = None  # for a cavity, the end mirror name
@@ -72,7 +101,7 @@ class BeamTrace:
         self.components = np.array([])  # holds component names in order
         self.comp_dict = {}
 
-        self.ABCD = np.array([[1, 0], [0, 1]])
+        self.abcd = np.array([[1, 0], [0, 1]])
         self.q = 0.0 + 1.0j  # q parameter
 
         self.total_length = 0.0
@@ -82,10 +111,12 @@ class BeamTrace:
         self.number_of_lenses = 0
         self.number_of_refractions = 0
 
+        return
+
     ##### set functions #####
-    def set_isCavity(self, isCavity):
-        """Sets the isCavity parameter to True or False.  Default is True"""
-        self.isCavity = isCavity
+    def set_is_cavity(self, is_cavity):
+        """Sets the is_cavity parameter to True or False.  Default is True"""
+        self.is_cavity = is_cavity
         return
 
     def set_seed_beam(self, q):
@@ -95,29 +126,29 @@ class BeamTrace:
 
     ##### get functions #####
     def get_q(self):
-        """Calculate q-parameter from ABCD matrix
+        """Calculate q-parameter from abcd matrix
         From Koji Arai T1300189:
         q = [(A - D) +- sqrt((A + D)^2 - 4) ]/(2C)
         """
-        A = self.ABCD[0, 0]
-        B = self.ABCD[0, 1]
-        C = self.ABCD[1, 0]
-        D = self.ABCD[1, 1]
-        q = ((A - D) + np.sqrt((A + D) ** 2 - 4 + 0j)) / (
-            2 * C
-        )  # Added the plus 0j to get complex numbers back
+        A = self.abcd[0, 0]
+        B = self.abcd[0, 1]
+        C = self.abcd[1, 0]
+        D = self.abcd[1, 1]
+
+        # Added the plus 0j to get complex numbers back
+        q = ((A - D) + np.sqrt((A + D) ** 2 - 4 + 0j)) / (2 * C)
         if np.imag(q) < 0:
-            q = np.conjugate(q)  # make imaginary part positve out of convention
+            q = np.conjugate(q)  # make imaginary part positive out of convention
         return q
 
     def get_total_cavity_gouy_phase(self, deg=True):
         """Calculate cavity round-trip accumulated gouy phase from the cav ABCD matrix
         From Koji Arai T1300189:
         gouy = sign(B) * arccos((A + D)/2)"""
-        A = self.ABCD[0, 0]
-        B = self.ABCD[0, 1]
-        C = self.ABCD[1, 0]
-        D = self.ABCD[1, 1]
+        A = self.abcd[0, 0]
+        B = self.abcd[0, 1]
+        C = self.abcd[1, 0]
+        D = self.abcd[1, 1]
         if deg == True:
             multiplier = 180 / np.pi
         else:
@@ -135,7 +166,7 @@ class BeamTrace:
         im_invq = -1 * np.imag(invq) * np.pi / self.wavelength  # = 1/w^2
         return np.sqrt(1.0 / im_invq)
 
-    def get_beam_RoC(self, q):
+    def get_beam_roc(self, q):
         """Calculate beam radius of curvature from the q-parameter
         From Kogelnik and Li DCC P660001:
         1/q = 1/R - j lambda/(pi * w^2)
@@ -151,7 +182,17 @@ class BeamTrace:
 
     ##### Add component functions #####
     def add_space(self, length, index_of_refraction=1, name=None):
-        """Adds a space to the beam path"""
+        """Adds a space to the beam path
+
+        Inputs:
+        -------
+        length: float
+            length of the space in meters
+        index_of_refraction: float
+            index of refraction of the space we are propagating in
+        name: string
+            name of the space, i.e. 'M1 to M2'
+        """
         if name == None:
             name = "space_{}".format(self.number_of_spaces)
 
@@ -168,12 +209,20 @@ class BeamTrace:
         self.comp_dict[name]["start_location"] = start_location
         self.comp_dict[name]["end_location"] = end_location
 
-        self.comp_dict[name]["ABCD"] = self.space(length, index_of_refraction)
+        self.comp_dict[name]["abcd"] = self.space(length, index_of_refraction)
         self.number_of_spaces += 1
         return
 
     def add_lens(self, focal_length, name=None):
-        """Adds a lens to the beam path"""
+        """Adds a thin lens to the beam path
+
+        Inputs:
+        -------
+        focal_length: float
+            focal length of the lens in meters
+        name: string
+            name of the lens, i.e. 'Lens1'
+        """
         if name == None:
             name = "lens_{}".format(self.number_of_spaces)
 
@@ -186,12 +235,22 @@ class BeamTrace:
         self.comp_dict[name]["focal_length"] = focal_length
         self.comp_dict[name]["location"] = location
 
-        self.comp_dict[name]["ABCD"] = self.lens(focal_length)
+        self.comp_dict[name]["abcd"] = self.lens(focal_length)
         self.number_of_lenses += 1
         return
 
     def add_mirror(self, radius_of_curvature, index_of_refraction=1, name=None):
-        """Adds a mirror to the beam path"""
+        """Adds a mirror to the beam path
+
+        Inputs:
+        -------
+        radius_of_curvature: float
+            radius of curvature of the mirror in meters
+        index_of_refraction: float
+            index of refraction of the space we are propagating in
+        name: string
+            name of the mirror, i.e. 'M1'
+        """
         if name == None:
             name = "mirror_{}".format(self.number_of_spaces)
 
@@ -205,7 +264,7 @@ class BeamTrace:
         self.comp_dict[name]["location"] = location
         self.comp_dict[name]["index_of_refraction"] = index_of_refraction
 
-        self.comp_dict[name]["ABCD"] = self.mirror(
+        self.comp_dict[name]["abcd"] = self.mirror(
             radius_of_curvature, index_of_refraction=index_of_refraction
         )
         self.number_of_mirrors += 1
@@ -232,7 +291,7 @@ class BeamTrace:
         self.comp_dict[name]["index_of_refraction1"] = index_of_refraction1
         self.comp_dict[name]["index_of_refraction2"] = index_of_refraction2
 
-        self.comp_dict[name]["ABCD"] = self.refraction(
+        self.comp_dict[name]["abcd"] = self.refraction(
             radius_of_curvature, index_of_refraction1, index_of_refraction2
         )
         self.number_of_lenses += 1
@@ -246,32 +305,38 @@ class BeamTrace:
     def lens(self, focal_length):
         """Returns ABCD numpy matrix of a lens"""
         if focal_length == np.inf:
-            ABCD = np.array([[1, 0], [0, 1]])
+            abcd = np.array([[1, 0], [0, 1]])
         else:
-            ABCD = np.array([[1, 0], [-1 / focal_length, 1]])
-        return ABCD
+            abcd = np.array([[1, 0], [-1 / focal_length, 1]])
+
+        return abcd
 
     def mirror(self, radius_of_curvature, index_of_refraction=1):
         """Returns ABCD numpy matrix of a lens"""
         if radius_of_curvature == np.inf:
-            ABCD = np.array([[1, 0], [0, 1]])
+            abcd = np.array([[1, 0], [0, 1]])
         else:
-            ABCD = np.array(
+            abcd = np.array(
                 [[1, 0], [-2 * index_of_refraction / radius_of_curvature, 1]]
             )
-        return ABCD
+
+        return abcd
 
     def refraction(
         self, radius_of_curvature, index_of_refraction1, index_of_refraction2
     ):
-        """Returns ABCD numpy matrix of a refracted beam at a curved surface. n1 is the refractive index of the starting medium, n2 is the index of the medium being entered"""
+        """Returns ABCD numpy matrix of a refracted beam at a curved surface.
+        n1 is the refractive index of the starting medium,
+        n2 is the index of the medium being entered
+        """
         if radius_of_curvature == np.inf:
-            ABCD = np.array([[1, 0], [0, n1 / n2]])
+            abcd = np.array([[1, 0], [0, n1 / n2]])
         elif n1 == n2:
-            ABCD = np.array([[1, 0], [0, 1]])
+            abcd = np.array([[1, 0], [0, 1]])
         else:
-            ABCD = np.array([[1, 0], [(n1 - n2) / (n2 * radius_of_curvature), n1 / n2]])
-        return ABCD
+            abcd = np.array([[1, 0], [(n1 - n2) / (n2 * radius_of_curvature), n1 / n2]])
+
+        return abcd
 
     def get_component_locations(self):
         """Returns two arrays, one of mirror and lens names, the other their z-location.
@@ -308,10 +373,10 @@ class BeamTrace:
         """Prints the cavity components added so far"""
         print()
         print(
-            "{name:<20}\t{number:>20}\t{RoC:>20}\t{z:>20}\t{index:>20}".format(
+            "{name:<20}\t{number:>20}\t{roc:>20}\t{z:>20}\t{index:>20}".format(
                 name="Mirror",
                 number="Order Number",
-                RoC="Curve Radius",
+                roc="Curve Radius",
                 z="z-Location",
                 index="Refraction Index",
             )
@@ -321,10 +386,10 @@ class BeamTrace:
             if self.comp_dict[key]["type"] == "mirror":
                 cd = self.comp_dict[key]
                 print(
-                    "{name:<20}\t{number:>20}\t{RoC:>20}\t{z:>20}\t{index:>20}".format(
+                    "{name:<20}\t{number:>20}\t{roc:>20}\t{z:>20}\t{index:>20}".format(
                         name=key,
                         number=cd["number"],
-                        RoC=cd["radius_of_curvature"],
+                        roc=cd["radius_of_curvature"],
                         z=cd["location"],
                         index=cd["index_of_refraction"],
                     )
@@ -352,10 +417,10 @@ class BeamTrace:
                 )
         print()
         print(
-            "{name:<20}\t{number:>20}\t{RoC:>20}\t{z:>20}\t{index1:>20}\t{index2:>20}".format(
+            "{name:<20}\t{number:>20}\t{roc:>20}\t{z:>20}\t{index1:>20}\t{index2:>20}".format(
                 name="Refractions",
                 number="Order Number",
-                RoC="Curve Radius",
+                roc="Curve Radius",
                 z="z-Location",
                 index1="Refraction Index 1",
                 index2="Refraction Index 2",
@@ -366,10 +431,10 @@ class BeamTrace:
             if self.comp_dict[key]["type"] == "refraction":
                 cd = self.comp_dict[key]
                 print(
-                    "{name:<20}\t{number:>20}\t{RoC:>20}\t{z:>20}\t{index1:>20}\t{index2:>20}".format(
+                    "{name:<20}\t{number:>20}\t{roc:>20}\t{z:>20}\t{index1:>20}\t{index2:>20}".format(
                         name=key,
                         number=cd["number"],
-                        RoC=cd["radius_of_curvature"],
+                        roc=cd["radius_of_curvature"],
                         z=cd["location"],
                         index1=cd["index_of_refraction1"],
                         index2=cd["index_of_refraction2"],
@@ -405,48 +470,67 @@ class BeamTrace:
         print()
         return
 
-    def check_stability(self, verbose=False):
+    def check_stability(self):
         """Tells you if cavity is stable or not"""
-        A = self.ABCD[0, 0]
-        B = self.ABCD[0, 1]
-        C = self.ABCD[1, 0]
-        D = self.ABCD[1, 1]
+        A = self.abcd[0, 0]
+        B = self.abcd[0, 1]
+        C = self.abcd[1, 0]
+        D = self.abcd[1, 1]
         stability_criterion = 0.5 * (A + D)
-        if verbose:
+        if self.verbose:
             print("(A + D)/2 = {:.3f}".format(stability_criterion))
         if -1 < stability_criterion and stability_criterion < 1:
-            if verbose:
+            if self.verbose:
                 print("Cavity is STABLE")
-            self.isStable = True
+            self.is_stable = True
         else:
             print("Cavity is NOT STABLE")
-            self.isStable = False
-        return self.isStable
+            self.is_stable = False
+        return self.is_stable
 
-    def check_unity(self, verbose=False):
-        """Checks if ABCD matrix is unity, A*D - B*C = 1"""
-        A = self.ABCD[0, 0]
-        B = self.ABCD[0, 1]
-        C = self.ABCD[1, 0]
-        D = self.ABCD[1, 1]
+    def check_unity(self):
+        """Checks if abcd matrix is unity, A*D - B*C = 1"""
+        A = self.abcd[0, 0]
+        B = self.abcd[0, 1]
+        C = self.abcd[1, 0]
+        D = self.abcd[1, 1]
         unity = A * D - B * C
         if np.abs(unity - 1.0) < 1e-6:
-            if verbose:
-                print("Cavity ABCD is unity")
-            self.isUnity = True
+            if self.verbose:
+                print("Cavity abcd is unity")
+            self.is_unity = True
         else:
-            if verbose:
-                print("Cavity ABCD is NOT unity")
-            self.isUnity = False
-        return self.isUnity
+            if self.verbose:
+                print("Cavity abcd is NOT unity")
+            self.is_unity = False
+        return self.is_unity
+
+    def calculate_cavity_abcd(self):
+        """Calculates the total abcd matrix for the cavity as constructed.
+
+        If is_cavity == False, does nothing
+        If number_of_mirrors < 2, does nothing
+
+        If is_single_pass == False,
+            assumes the first and last two mirrors added form a linear, back-and-forth propagating cavity.
+            Starts propagating from the first mirror into the first space (z=0) toward the second mirror.
+
+        If is_single_pass == True,
+            assumes the first mirror added is the input coupler,
+            and last space added is the path from the last mirror to the input coupler.
+            Computes the round trip ABCD starting and ending at the first mirror location.
+            This will require at least three mirrors and three spaces.
 
-    def calculate_cavity_ABCD(self):
-        """Calculates the total ABCD matrix for the cavity as constructed.
-        Assumes the first and last two mirrors added form a cavity.
-        Starts propagating from the first mirror into the first space (z=0) toward the second mirror.
         Tells you if the cavity is stable or not.
         If the cavity is stable, stores the input q-parameter expected for the stable cavity in self.q_input.
         """
+        if not self.is_cavity:
+            print("\033[91m")
+            print("ERROR in BeamTrace.calculate_cavity_abcd():")
+            print("\033[91m")
+            print(f"is_cavity = {self.is_cavity}, cavity eigenmode is not defined")
+            return
+
         if self.number_of_mirrors < 2:
             print(
                 'Number of mirrors in "cavity" is only {}'.format(
@@ -455,44 +539,85 @@ class BeamTrace:
             )
             print("Add more mirrors!")
             return
-        for ii, name in enumerate(self.components):
-            if (
-                self.comp_dict[name]["type"] == "mirror"
-                and self.comp_dict[name]["number"] == 0
-            ):
-                self.input_mirror_name = name
-                input_mirror_index = ii
-            if (
-                self.comp_dict[name]["type"] == "mirror"
-                and self.comp_dict[name]["number"] == self.number_of_mirrors - 1
-            ):
-                self.end_mirror_name = name
-                end_mirror_index = ii
 
-        for name in self.components[input_mirror_index + 1 : end_mirror_index + 1]:
-            tempABCD = self.comp_dict[name]["ABCD"]
-            self.ABCD = np.dot(tempABCD, self.ABCD)
+        if not self.is_single_pass:
 
-        for name in reversed(self.components[input_mirror_index:end_mirror_index]):
-            tempABCD = self.comp_dict[name]["ABCD"]
-            self.ABCD = np.dot(tempABCD, self.ABCD)
+            # Find the input mirror and end mirror
+            for ii, name in enumerate(self.components):
+                if (
+                    self.comp_dict[name]["type"] == "mirror"
+                    and self.comp_dict[name]["number"] == 0
+                ):
+                    self.input_mirror_name = name
+                    input_mirror_index = ii
+                if (
+                    self.comp_dict[name]["type"] == "mirror"
+                    and self.comp_dict[name]["number"] == self.number_of_mirrors - 1
+                ):
+                    self.end_mirror_name = name
+                    end_mirror_index = ii
+
+            # Follow the first pass
+            for name in self.components[input_mirror_index + 1 : end_mirror_index + 1]:
+                temp_abcd = self.comp_dict[name]["abcd"]
+                self.abcd = np.dot(temp_abcd, self.abcd)
+
+            # Follow the second pass (first pass backward)
+            for name in reversed(self.components[input_mirror_index:end_mirror_index]):
+                temp_abcd = self.comp_dict[name]["abcd"]
+                self.abcd = np.dot(temp_abcd, self.abcd)
+
+        elif self.is_single_pass:
+            if self.number_of_mirrors < 3:
+                print(
+                    "Number of mirrors in single-pass cavity is only {}".format(
+                        self.number_of_mirrors
+                    )
+                )
+                print("Needs at least three mirrors to form a uni-directional cavity.")
+
+            # Find the input coupler (both input and end mirror), and end space
+            for ii, name in enumerate(self.components):
+                if (
+                    self.comp_dict[name]["type"] == "mirror"
+                    and self.comp_dict[name]["number"] == 0
+                ):
+                    self.input_mirror_name = name
+                    input_mirror_index = ii
+                    self.end_mirror_name = name
+
+                if (
+                    self.comp_dict[name]["type"] == "space"
+                    and self.comp_dict[name]["number"] == self.number_of_spaces - 1
+                ):
+                    self.end_space_name = name
+                    end_space_index = ii
+
+            # Follow the single pass
+            for name in self.components[input_mirror_index + 1 : end_space_index + 1]:
+                temp_abcd = self.comp_dict[name]["abcd"]
+                self.abcd = np.dot(temp_abcd, self.abcd)
+
+            # Add in the first mirror reflection at the very end
+            temp_abcd = self.comp_dict[self.input_mirror_name]["abcd"]
+            self.abcd = np.dot(temp_abcd, self.abcd)
 
         self.check_unity()
         self.check_stability()
-        if self.isStable and self.q_input == None:
+        if self.is_stable and self.q_input == None:
             self.q = self.get_q()
             self.q_input = self.q
             self.w_input = self.get_beam_radius(self.q)
-            self.RoC_input = self.get_beam_RoC(self.q)
+            self.roc_input = self.get_beam_roc(self.q)
 
         return
 
-    def calc_q_from_ABCD(self, q_in, ABCD):
+    def calc_q_from_abcd(self, q_in, abcd):
         """Takes input q and ABCD matrix and returns output q"""
-        A = ABCD[0, 0]
-        B = ABCD[0, 1]
-        C = ABCD[1, 0]
-        D = ABCD[1, 1]
+        A = abcd[0, 0]
+        B = abcd[0, 1]
+        C = abcd[1, 0]
+        D = abcd[1, 1]
         q_out = (A * q_in + B) / (C * q_in + D)
         return q_out
 
@@ -540,7 +665,8 @@ class BeamTrace:
         return
 
     def scan_beam(self, steps=500):
-        """Scans the beam.  Needs only an q_input via set_seed_beam() and a space via add_space.
+        """Scans the beam.
+        Needs only an q_input via set_seed_beam() and a space via add_space.
         Works with plot_beam()
 
         Example:
@@ -579,12 +705,12 @@ class BeamTrace:
         last_location = 0.0
 
         space_name = self.get_space(0.0)
-        space_ABCD = self.comp_dict[space_name]["ABCD"]
+        space_abcd = self.comp_dict[space_name]["abcd"]
         space_index_of_refraction = self.comp_dict[space_name]["index_of_refraction"]
 
-        permanent_ABCD = np.array(
+        permanent_abcd = np.array(
             [[1, 0], [0, 1]]
-        )  # make an ABCD matrix to scan over z
+        )  # make an abcd matrix to scan over z
 
         ww = np.array([])
         gouy = np.array([])
@@ -598,29 +724,29 @@ class BeamTrace:
             # if we've reached the next space, separated by a component
             if current_space_name != space_name:
 
-                # First, multiply in the old space into the ABCD permanently
-                permanent_ABCD = np.dot(space_ABCD, permanent_ABCD)
+                # First, multiply in the old space into the abcd permanently
+                permanent_abcd = np.dot(space_abcd, permanent_abcd)
 
                 # Store the current space
                 space_name = self.get_space(z_temp)
-                space_ABCD = self.comp_dict[space_name]["ABCD"]
+                space_abcd = self.comp_dict[space_name]["abcd"]
                 space_index_of_refraction = self.comp_dict[space_name][
                     "index_of_refraction"
                 ]
 
-                # Get current component name, location, ABCD
+                # Get current component name, location, abcd
                 last_name = names[next_index]
                 last_location = locations[next_index]
-                comp_ABCD = self.comp_dict[last_name]["ABCD"]
-                permanent_ABCD = np.dot(comp_ABCD, permanent_ABCD)
+                comp_abcd = self.comp_dict[last_name]["abcd"]
+                permanent_abcd = np.dot(comp_abcd, permanent_abcd)
 
                 # Reset the gouy phase reference
                 try:
                     last_gouy = gouy[-1]
                 except IndexError:
                     last_gouy = 0.0
-                # get q_perm from q_in and the "permanent" ABCD
-                q_perm = self.calc_q_from_ABCD(self.q_input, permanent_ABCD)
+                # get q_perm from q_in and the "permanent" abcd
+                q_perm = self.calc_q_from_abcd(self.q_input, permanent_abcd)
                 # reset the accumulated gouy phase reference
                 gouy_ref = self.get_beam_gouy(q_perm) - last_gouy
 
@@ -628,21 +754,21 @@ class BeamTrace:
 
             # usual calcs
             temp_length = z_temp - last_location
-            temp_space_ABCD = self.space(
+            temp_space_abcd = self.space(
                 temp_length, index_of_refraction=space_index_of_refraction
             )
-            # get the scan's temp ABCD matrix at z_temp
-            temp_ABCD = np.dot(temp_space_ABCD, permanent_ABCD)  
+            # get the scan's temp abcd matrix at z_temp
+            temp_abcd = np.dot(temp_space_abcd, permanent_abcd)
 
-            # get q_out from q_in and the temp ABCD
-            q_out = self.calc_q_from_ABCD(self.q_input, temp_ABCD)  
+            # get q_out from q_in and the temp abcd
+            q_out = self.calc_q_from_abcd(self.q_input, temp_abcd)
 
             w_out = self.get_beam_radius(q_out)
-            
+
             # gets "pure" gouy phase from beam q-parameter
             gouy_out = self.get_beam_gouy(q_out)
             # subtracts away the reference gouy phase to get relative phase added
-            gouy_accumulated = gouy_out - gouy_ref  
+            gouy_accumulated = gouy_out - gouy_ref
 
             ww = np.append(ww, w_out)
             qq = np.append(qq, q_out)
@@ -661,21 +787,28 @@ class BeamTrace:
 
     def scan_cavity(self, steps=500, round_trip=False):
         """Scans the cavity along the axis of propagation (aka z-axis) from input to end mirror.
+
         Inputs:
-        steps = number of points on the z-axis to scan at.  z goes from 0 to the cavity length, unless round_trip is True.
-        round_trip = scans from front mirror to end mirror and back again.  z goes from 0 to 2*cavity length.
+        -------
+        steps: int
+            number of points on the z-axis to scan at.
+            z goes from 0 to the cavity length, unless round_trip is True, where it goes to 2 * length.
+        round_trip: bool
+            scans along entire defined beam space
+
+        Outputs:
 
         Returns arrays of the distance z, beam radius w, accumulated gouy phase, and q-parameters along the z-axis:
-        z, w, gouy, q = scan_cavity()
+        zz, ww, gouy, qq = scan_cavity()
         """
 
         if self.q_input == None:
-            print("self.isCavity = {}".format(self.isCavity))
-            if self.isCavity:
+            print("self.is_cavity = {}".format(self.is_cavity))
+            if self.is_cavity:
                 print(
-                    "Running calculate_cavity_ABCD() to find the fundamental eigenmode to use as the seed beam q-parameter"
+                    "Running calculate_cavity_abcd() to find the fundamental eigenmode to use as the seed beam q-parameter"
                 )
-                self.calculate_cavity_ABCD()
+                self.calculate_cavity_abcd()
             else:
                 print("Running with default seed beam q = {}".format(self.q))
                 self.q_input = self.q
@@ -683,7 +816,17 @@ class BeamTrace:
         z_start = 0
         z_end = self.total_length
         if round_trip:
-            length_scaler = 2
+            if self.is_single_pass:
+                print("\033[92m")
+                print(
+                    f"is_single_pass = {self.is_single_pass}, but round_trip = {round_trip}"
+                )
+                print("\033[0m")
+                print(f"a round trip is a single pass through this cavity")
+
+                length_scaler = 1
+            else:
+                length_scaler = 2
         else:
             length_scaler = 1
         zz = np.linspace(z_start, length_scaler * z_end, steps)
@@ -700,12 +843,12 @@ class BeamTrace:
         past_last_component = False
 
         space_name = self.get_space(0.0)
-        space_ABCD = self.comp_dict[space_name]["ABCD"]
+        space_abcd = self.comp_dict[space_name]["abcd"]
         space_index_of_refraction = self.comp_dict[space_name]["index_of_refraction"]
 
-        permanent_ABCD = np.array(
+        permanent_abcd = np.array(
             [[1, 0], [0, 1]]
-        )  # make an ABCD matrix to scan over z
+        )  # make an abcd matrix to scan over z
 
         ww = np.array([])
         gouy = np.array([])
@@ -719,8 +862,8 @@ class BeamTrace:
                     z_temp >= next_location and not past_last_component
                 ):  # if we've reached the next component that's not a space, and it's not the last component
 
-                    # First, multiply in the old space into the ABCD permanently
-                    permanent_ABCD = np.dot(space_ABCD, permanent_ABCD)
+                    # First, multiply in the old space into the abcd permanently
+                    permanent_abcd = np.dot(space_abcd, permanent_abcd)
 
                     # Get the new component name and location
                     last_name = names[next_index]
@@ -728,23 +871,23 @@ class BeamTrace:
 
                     # Get the new space
                     space_name = self.get_space(z_temp)
-                    space_ABCD = self.comp_dict[space_name]["ABCD"]
+                    space_abcd = self.comp_dict[space_name]["abcd"]
                     space_index_of_refraction = self.comp_dict[space_name][
                         "index_of_refraction"
                     ]
 
-                    # Get current component ABCD
-                    comp_ABCD = self.comp_dict[last_name]["ABCD"]
-                    permanent_ABCD = np.dot(comp_ABCD, permanent_ABCD)
+                    # Get current component abcd
+                    comp_abcd = self.comp_dict[last_name]["abcd"]
+                    permanent_abcd = np.dot(comp_abcd, permanent_abcd)
 
                     # Reset the gouy phase reference
                     try:
                         last_gouy = gouy[-1]
                     except IndexError:
                         last_gouy = 0.0
-                    q_perm = self.calc_q_from_ABCD(
-                        self.q_input, permanent_ABCD
-                    )  # get q_perm from q_in and the "permanent" ABCD
+                    q_perm = self.calc_q_from_abcd(
+                        self.q_input, permanent_abcd
+                    )  # get q_perm from q_in and the "permanent" abcd
                     gouy_ref = (
                         self.get_beam_gouy(q_perm) - last_gouy
                     )  # reset the accumulated gouy phase reference
@@ -761,8 +904,8 @@ class BeamTrace:
 
                 back_tracking = True
 
-                # First, multiply in the old space into the ABCD permanently
-                permanent_ABCD = np.dot(space_ABCD, permanent_ABCD)
+                # First, multiply in the old space into the abcd permanently
+                permanent_abcd = np.dot(space_abcd, permanent_abcd)
 
                 # Get the new component name and location
                 last_name = names[next_index]
@@ -770,19 +913,19 @@ class BeamTrace:
 
                 # Get the new space going backwards
                 space_name = self.get_space(2 * z_end - z_temp)
-                space_ABCD = self.comp_dict[space_name]["ABCD"]
+                space_abcd = self.comp_dict[space_name]["abcd"]
                 space_index_of_refraction = self.comp_dict[space_name][
                     "index_of_refraction"
                 ]
 
-                # Get current component ABCD
-                comp_ABCD = self.comp_dict[last_name]["ABCD"]
-                permanent_ABCD = np.dot(comp_ABCD, permanent_ABCD)
+                # Get current component abcd
+                comp_abcd = self.comp_dict[last_name]["abcd"]
+                permanent_abcd = np.dot(comp_abcd, permanent_abcd)
 
                 # Reset the gouy phase reference
-                q_perm = self.calc_q_from_ABCD(
-                    self.q_input, permanent_ABCD
-                )  # get q_perm from q_in and the "permanent" ABCD
+                q_perm = self.calc_q_from_abcd(
+                    self.q_input, permanent_abcd
+                )  # get q_perm from q_in and the "permanent" abcd
                 gouy_ref = (
                     self.get_beam_gouy(q_perm) - gouy[-1]
                 )  # reset the accumulated gouy phase reference
@@ -793,8 +936,8 @@ class BeamTrace:
                 if (
                     z_temp >= 2 * z_end - locations[next_index]
                 ):  # if we've reached the next component that's not a space
-                    # First, multiply in the old space into the ABCD permanently
-                    permanent_ABCD = np.dot(space_ABCD, permanent_ABCD)
+                    # First, multiply in the old space into the abcd permanently
+                    permanent_abcd = np.dot(space_abcd, permanent_abcd)
 
                     # Get the new component name and location
                     last_name = names[next_index]
@@ -802,19 +945,19 @@ class BeamTrace:
 
                     # Get the new space going backwards
                     space_name = self.get_space(2 * z_end - z_temp)
-                    space_ABCD = self.comp_dict[space_name]["ABCD"]
+                    space_abcd = self.comp_dict[space_name]["abcd"]
                     space_index_of_refraction = self.comp_dict[space_name][
                         "index_of_refraction"
                     ]
 
-                    # Get current component ABCD
-                    comp_ABCD = self.comp_dict[last_name]["ABCD"]
-                    permanent_ABCD = np.dot(comp_ABCD, permanent_ABCD)
+                    # Get current component abcd
+                    comp_abcd = self.comp_dict[last_name]["abcd"]
+                    permanent_abcd = np.dot(comp_abcd, permanent_abcd)
 
                     # Reset the gouy phase reference
-                    q_perm = self.calc_q_from_ABCD(
-                        self.q_input, permanent_ABCD
-                    )  # get q_perm from q_in and the "permanent" ABCD
+                    q_perm = self.calc_q_from_abcd(
+                        self.q_input, permanent_abcd
+                    )  # get q_perm from q_in and the "permanent" abcd
                     gouy_ref = (
                         self.get_beam_gouy(q_perm) - gouy[-1]
                     )  # reset the accumulated gouy phase reference
@@ -825,17 +968,17 @@ class BeamTrace:
                     next_index -= 1  # increment the component counter
 
             temp_length = z_temp - last_location
-            temp_space_ABCD = self.space(
+            temp_space_abcd = self.space(
                 temp_length, index_of_refraction=space_index_of_refraction
             )
 
-            temp_ABCD = np.dot(
-                temp_space_ABCD, permanent_ABCD
-            )  # get the scan's temp ABCD matrix at z_temp
+            temp_abcd = np.dot(
+                temp_space_abcd, permanent_abcd
+            )  # get the scan's temp abcd matrix at z_temp
 
-            q_out = self.calc_q_from_ABCD(
-                self.q_input, temp_ABCD
-            )  # get q_out from q_in and the temp ABCD
+            q_out = self.calc_q_from_abcd(
+                self.q_input, temp_abcd
+            )  # get q_out from q_in and the temp abcd
 
             w_out = self.get_beam_radius(q_out)
             gouy_out = self.get_beam_gouy(
